@@ -547,6 +547,12 @@ class StagingQueue(models.Model):
     aha_input = models.ForeignKey('StagingTable', related_name='aha_input',
                                   help_text='AHALINK_SOURCE, if required.',
                                   null=True, default=None, blank=True)
+    severity_input = models.ForeignKey('StagingTable', related_name='severity_input',
+                                  help_text='SEVERITY_SOURCE, if required.',
+                                  null=True, default=None, blank=True)
+    dx_pr_grps_input = models.ForeignKey('StagingTable', related_name='dx_pr_grps_input',
+                                  help_text='DX_PR_GRPS_SOURCE, if required.',
+                                  null=True, default=None, blank=True)
     
     
     # Anyone looking at this code must, by now, wonder why more of
@@ -711,6 +717,8 @@ class StagingTable(models.Model):
         ('CHARGES_SOURCE','Charges data, from source (no wide-to-long conversion)'),
         ('DAYSTOEVENT_SOURCE','DaysToEvent and VisitLink data, from source (straight csv load)'),
         ('AHALINK_SOURCE','American Hospital Association link data, from source'),
+        ('SEVERITY_SOURCE','AHRQ comorbidity measures, from source'),
+        ('DX_PR_GRPS_SOURCE','DX_PR_GRPS, from source'),
         ('CHARGES','Charges data in long format (converted from wide source if necessary)'),
         ('DX','Diagnoses data in long format (from CORE_SOURCE)'),
         ('PR','Procedures data in long format (from CORE_SOURCE)'),
@@ -824,7 +832,7 @@ class Column(models.Model):
             yr = f.year
             name = self.name
             qs = ReferenceColumn.objects.filter(source=ds, state=st,
-                                                year=yr, name=name)
+                                                year=yr, name__iexact=name)
             if len(qs) == 1:
                 self.ref_col = qs[0]
                 self.save()
@@ -842,7 +850,7 @@ class Column(models.Model):
                 return False
         else:
             logger.warning("match_ref_col() called on Column %s with ref_col already set to ReferenceColumn %s. match_ref_col() will not proceed." % (self.pk, self.ref_col.pk))
-            return False
+            return None
     
     
     def validate(self, tolerance=0.01):
@@ -861,7 +869,7 @@ class Column(models.Model):
             # validation.
             match_attempt = self.match_ref_col()
             if match_attempt == True:
-                return self.validate(self, tolerance=tolerance)
+                return self.validate(tolerance=tolerance)
             else:
                 return None
         else:
@@ -915,7 +923,7 @@ class Column(models.Model):
                     self.save()
                     return False
                 elif True in results:
-                    self.integrity_status = 'VERIFIED_AUTO'
+                    self.integrity_status = 'VALID_AUTO'
                     self.save()
                     return True
                 else:
