@@ -205,7 +205,15 @@ def import_dispatch(self, importqueue_pk, insert_size=5, slice_size=1000):
     
     # FROM HERE BELOW, SPLIT OFF PSYCOPG2 VS NOT
     if ('psycopg2' in DB_BACKEND and (
-            ((dsabbr.upper() in ['CORE', 'BASE', 'CHGS', 'DTE', 'AHAL', 'DX_PR_GRPS']) or
+            ((dsabbr.upper() in [
+                    'CORE',
+                    'BASE',
+                    'CHGS',
+                    'DTE',
+                    'AHAL',
+                    'DX_PR_GRPS',
+                    'SEVERITY'
+                    ]) or
                 (dsabbr.upper() in ['CHGS'] and meta_is_long(load.get_meta()))
                 )
             )
@@ -249,7 +257,9 @@ def pg_import_file(self, importqueue_pk, drop_rawload=True):
         'CORE': 'CORE_SOURCE',
         'CHGS': 'CHARGES_SOURCE',
         'DTE': 'DAYSTOEVENT_SOURCE',
-        'AHAL': 'AHALINK_SOURCE'
+        'AHAL': 'AHALINK_SOURCE',
+        'SEVERITY': 'SEVERITY_SOURCE',
+        'DX_PR_GRPS': 'DX_PR_GRPS_SOURCE'
     }
     
     if dsabbr in supported_imports:
@@ -775,10 +785,11 @@ def pg_stage(self, stagingqueue_pk):
                 
                 from pyhcup.parser import lm_reverse
                 fields_in = [x for x in meta.field if lm_reverse('CHGS', x) is not False]
-                fields_out = [lm_reverse('CHGS', x)
-                              for x in meta.field
-                              if lm_reverse('CHGS', x) is not False
-                              ]
+                fields_out = [
+                    lm_reverse('CHGS', x)
+                    for x in meta.field
+                    if lm_reverse('CHGS', x) is not False
+                ]
                 
                 # these are allowable fields that won't map with lm_reverse
                 id_fields = ['KEY', 'STATE', 'YEAR']
