@@ -23,7 +23,7 @@ from django.db.models import Q
 
 # local project and app packages
 import djhcup_staging
-from djhcup_staging.models import State, DataSource, FileType, File, Column, ImportQueue, ImportBatch, StagingTable, StagingBatch
+from djhcup_staging.models import State, DataSource, FileType, File, Column, ImportQueue, ImportBatch, StagingTable, StagingBatch, ReferenceColumn
 from djhcup_staging.utils.misc import dead_batches
 
 
@@ -328,6 +328,14 @@ def file_match(request):
     return file_inventory(request, msg_pass_through=messages)
 
 
+def col_match(request):
+    """Attempts to match Column records from imported files with ReferenceColumn records
+    """
+    messages = []
+
+    unmatch_cols = Column.objects.filter(ref_col=None)
+    pass
+
 def src_gen_master_table(request, source_id):
     """For wide data, use all known loadfiles for source and generate one master table. For long data (or data which can be longed), make the corresponding fixed-style table.
     """
